@@ -8,7 +8,12 @@ logger = logger('SocketClient')
 class SocketClient:
     """Create socket and establish connect to service using tuple host+port"""
 
-    def __init__(self, host: str, port: int = 0, initialize: bool = False, logger_enabled: bool = True):
+    def __init__(self,
+                 host: str,
+                 port: int = 0,
+                 initialize: bool = False,
+                 logger_enabled: bool = True,
+                 connection_timeout: int = None):
         """Create and connect client to a remote host.
 
         :param host: Host IP
@@ -19,12 +24,13 @@ class SocketClient:
 
         self.host = host
         self.port = port
-        self.logger_enabled = logger_enabled
         self.logger = logger
+        self.logger.disabled = not logger_enabled
+        self.connection_timeout = connection_timeout
 
         if initialize:
             try:
-                self.client = socket.create_connection((self.host, self.port), timeout=7)
+                self.client = self.connect(timeout=self.connection_timeout)
             except ConnectionRefusedError as err:
                 self.logger.error(f'Cannot establish socket connection to {self.host}:{self.port}. {err}')
             except socket.gaierror as err:
@@ -36,6 +42,14 @@ class SocketClient:
     def __str__(self):
         return str(self._socket_response())
 
+    def connect(self, timeout: int = None):
+        """Create connection
+
+        :param timeout:
+        :return:
+        """
+        return socket.create_connection((self.host, self.port), timeout=timeout)
+
     def is_socket_available(
             self, port: int = 0,
             host: str = None,
